@@ -14,8 +14,8 @@ from numpy import nan, inf
 
 from la.flarry import (union, intersection, stack, panel, cov, rand, randn,
                        align, align_raw, binaryop, add, subtract, multiply,
-                       divide)
-from la.util.report import info                     
+                       divide, unique)
+from la.util.report import info
 from la.version import __version__
 from la.util import testing
 
